@@ -23,9 +23,15 @@ impl<'a> Route<'a> {
 
 impl RequestExt for Request {
     fn route(&self) -> Route<'_> {
+        let path = cleanup_path(self.uri().path());
+
         Route {
             method: self.method(),
-            segments: cleanup_path(self.uri().path()).split('/').collect(),
+            segments: if path.is_empty() {
+                Vec::new()
+            } else {
+                path.split('/').collect()
+            },
         }
     }
 
@@ -50,3 +56,19 @@ impl IntoResponse for serde_urlencoded::de::Error {
         StatusCode::BAD_REQUEST.into_response()
     }
 }
+
+#[cfg(test)]
+mod tests {
+    use super::RequestExt;
+    use crate::Body;
+    use http::Method;
+
+    #[test]
+    fn test_root_path() {
+        let req = http::Request::builder()
+            .uri("https://example.org/")
+            .body(Body::empty())
+            .unwrap();
+        assert_eq!(req.route().as_tuple(), (&Method::GET, &[] as &[&str]));
+    }
+}
