@@ -173,7 +173,7 @@ impl<S> Cors<S> {
             Some(origin) => origin,
             None => {
                 // not a CORS request
-                return inner.call(req).await.or_else(|err| err.into_response());
+                return inner.call(req).await;
             }
         };
 
@@ -217,7 +217,7 @@ impl<S> Cors<S> {
 
             res
         } else {
-            inner.call(req).await.or_else(|err| err.into_response())?
+            inner.call(req).await?
         };
 
         // add CORS header to response
